#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 double-conversion
version:              2.0.4.1
visibility:           public
id:                   double-conversion-2.0.4.1-9mCeIr11Wzm67KpO8eKTx
key:                  double-conversion-2.0.4.1-9mCeIr11Wzm67KpO8eKTx
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/Haskell-mouse/double-conversion
synopsis:
    Fast conversion between single and double precision floating point and text

description:
    A library that performs fast, accurate conversion between
    floating point and text.

    This library is implemented as bindings to the C++
    @double-conversion@ library written by Florian Loitsch at Google:
    <https://github.com/floitsch/double-conversion>.

    Now it can convert single precision numbers, and also it can create
    Builder, instead of bytestring or text.

    The '\''Text'\'' versions of these functions are about 30 times faster
    than the default '\''show'\'' implementation for the '\''Double'\'' type.

    The '\''ByteString'\'' versions are /slower/ than the '\''Text'\'' versions;
    roughly half the speed.  (This seems to be due to the cost of
    allocating '\''ByteString'\'' values via @malloc@.)

    Builder versions are slower on single value, but they are much faster on large number of values
    (up to 50x faster on list with 20000 doubles).

    As a final note, be aware that the @bytestring-show@ package is
    about 50% slower than simply using '\''show'\''.

category:             Text
abi:                  ef11a4e6ee7e75e9b2a3d12eae579961
exposed:              True
exposed-modules:
    Data.Double.Conversion.ByteString
    Data.Double.Conversion.Convertable Data.Double.Conversion.Text

hidden-modules:
    Data.Double.Conversion.Internal.FFI
    Data.Double.Conversion.Internal.ByteString
    Data.Double.Conversion.Internal.ByteStringBuilder
    Data.Double.Conversion.Internal.Text
    Data.Double.Conversion.Internal.TextBuilder

import-dirs:          /usr/lib/ghc-9.0.2/site-local/double-conversion-2.0.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/double-conversion-2.0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-double-conversion
hs-libraries:         HSdouble-conversion-2.0.4.1-9mCeIr11Wzm67KpO8eKTx
extra-libraries:      stdc++ double-conversion
depends:
    base-4.15.1.0 bytestring-0.10.12.1 ghc-prim-0.7.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-double-conversion/html/double-conversion.haddock

haddock-html:         /usr/share/doc/haskell-double-conversion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

